@@ -3,7 +3,6 @@ TTAinterface <- function() {
 #_________________________________________________________________________________________________Creation de la fenetre principale (tt) et des onglets
  Envir$tt <- tktoplevel()                                                                                                     # creation de la page principale
          tktitle(Envir$tt) <- paste("Temporal Trend Analysis interface (v", Envir$pversion, ")", sep="")                      # on donne un nom visible a cette page
-         tkwm.geometry(Envir$tt, "1200x700")                                                                                  # taille de la fenetre principale
 
          Envir$paned.tt <- tk2panedwindow(Envir$tt, orientation = "horizontal")
          Envir$topframe <- tkwidget(Envir$paned.tt,"labelframe", text= "",padx=0,pady=0)                                      # cadre de texte pour afficher les 2 boutons
@@ -37,21 +36,21 @@ TTAinterface <- function() {
          Envir$trend <- tk2notetab(nb, " 4-Diagnostics/TrendAnalyses ")
          tkconfigure(Envir$trend, borderwidth=10)
 
-#Creation de l'icon de l'interface
-Envir$ico <- tk2ico.create(file.path(path.package("TTAinterfaceTrendAnalysis"),"aide","iconTTA.ico",fsep=.Platform$file.sep))
-tk2ico.set(Envir$tt, Envir$ico)
+#Creation de l'icon de l'interface (seulement sous Windows)
+#Envir$ico <- tk2ico.create(file.path(path.package("TTAinterfaceTrendAnalysis"),"aide","iconTTA.ico",fsep=.Platform$file.sep))
+#tk2ico.set(Envir$tt, Envir$ico)
 
 #_______________________________________________________________________________________________________________________________________Onglet Raw Data
 
  getfile <- function(inipath) {
 
      ExampleValue <- tclvalue(ExampleValue)
-     if (ExampleValue=="1"){ inipath = file.path(path.package("TTAinterfaceTrendAnalysis"),"extdata", fsep=.Platform$file.sep )  }
+     if (ExampleValue=="1"){ inipath = file.path(path.package("TTAinterfaceTrendAnalysis"),"extdata", fsep=.Platform$file.sep)  }
      else { inipath = "C:/" }
 
      Envir$Name <- tclvalue(tkgetOpenFile(filetypes="{{TXT Files} {.txt}}", initialdir =inipath))                         # le chemin du fichier est assigne a Name
      if (Envir$Name=="") { return() };                                                                                    # si on ne selectionne rien on revient a la paga d'origine
-     Envir$Data <- read.table(Envir$Name, sep="\t", na.strings="", dec=".", header=T, fill=TRUE, check.names=FALSE)       # les donnees sont enregistre dans Data
+     Envir$Data <- read.table(Envir$Name, sep="\t", na.strings="", dec=".", header=T, fill=TRUE, check.names=F)       # les donnees sont enregistre dans Data
 
      Envir$Name.split <- data.frame(strsplit(Envir$Name, "/"))                                                            # morcelle le chemin du fichier (Name)
 
@@ -167,8 +166,8 @@ tk2ico.set(Envir$tt, Envir$ico)
                       for (i in 1:length(selection)) { Env$variables.selectionnees.temp <- Env$variables.selectionnees.temp[-min(selection)]  }}
                 else { tkmessageBox(message="No categorical factor selected !",type="ok",icon="info", title="!Warning!") } })
 
-     tkgrid(tklabel(Envir$Select, text="Select your categorical factor(s)"), row=0, column=0,rowspan=2)                        # titres des listes
-     tkgrid(tklabel(Envir$Select, text="Selected categorical factor(s)"), row=0, column=2,rowspan=2)                           # mise en page...
+     tkgrid(tklabel(Envir$Select, text="Categorical factor(s)"), row=0, column=0,rowspan=2)                        # titres des listes
+     tkgrid(tklabel(Envir$Select, text="Selected factor(s)"), row=0, column=2,rowspan=2)                           # mise en page...
      tkgrid(liste1,row=2,column=0,rowspan=2)
      tkgrid(bouton1,row=2,column=1)
      tkgrid(bouton2,row=3,column=1)
@@ -200,7 +199,7 @@ tk2ico.set(Envir$tt, Envir$ico)
                    Env2$variables.selectionnees.temp <- c(selection2) }
                 else { tkmessageBox(message="No variable selected !",type="ok",icon="info", title="!Warning!") }})
 
-     tkgrid(tklabel(Envir$Select, text="Select a parameter"), row=11, column=0,rowspan=2)            # titre des listes
+     tkgrid(tklabel(Envir$Select, text="Parameter(s)"), row=11, column=0,rowspan=2)            # titre des listes
      tkgrid(tklabel(Envir$Select, text="Selected parameter"), row=11, column=2,rowspan=2)            #       "
      tkgrid(liste3, row=13, column=0)
      tkgrid(bouton3, row=13, column=1)
@@ -234,7 +233,7 @@ tk2ico.set(Envir$tt, Envir$ico)
 
 #_______________________________________________________________________________________________________________________Sliders salinite et profondeur
 #_ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _Sliders pour les salinites
-     if (any(colnames(Envir$Data) == "Salinity") & any(!is.na(Envir$Data$Salinity))==TRUE) {                                                     # si une colonne S est presente
+     if (any(colnames(Envir$Data) == "Salinity") & any(!is.na(Envir$Data$Salinity))== TRUE) {                                                     # si une colonne S est presente
         if (class(Envir$Data$Salinity) == "numeric") {                                                                                                                                  #      et si c'est bien une valeur numerique  :
           sal1 <- tclVar(min(Envir$Data$Salinity, na.rm=TRUE))                                                                                                                    # prend la valeur mini de la salinite
           slider1 <- tk2scale(Envir$Select, from=min(Envir$Data$Salinity, na.rm=TRUE), to=max(Envir$Data$Salinity, na.rm=TRUE),        # slider coulissant entre...
@@ -321,8 +320,8 @@ tk2ico.set(Envir$tt, Envir$ico)
             if (is.numeric(Envir$Data$Dates) == TRUE ) { years <- Envir$Data$Dates } else {
             d <- as.Date(Envir$Data$Dates, format="%Y-%m-%d")                                                                                      # formattage de la date
             years <- as.numeric(format(d, format = "%Y")) }                                                                                             # on recupere les annees
-
-            if ( is.na(d) == FALSE ) {} else { return(tkmessageBox(message="Wrong date format: must be 'yyy-mm-dd'"
+        
+            if ( anyNA(d) == FALSE ) {} else { return(tkmessageBox(message="Wrong date format: must be 'yyyy-mm-dd'"
                                                                    ,icon = "warning", type = "ok", title="!Warning!")) }
 
             year1 <- tclVar(min(years, na.rm=TRUE))                                                                                                          # boite de texte avec fleches
@@ -454,7 +453,7 @@ tk2ico.set(Envir$tt, Envir$ico)
          tkgrid(tklabel(LabeledFrame1,text="Remove outliers ?"), column=0, row=2, sticky="w")
          tkgrid(cb3, column=1, row=2)
 
-         selectBox<-NULL                                                                                                                                                                    # radio button pour les boxplots
+         selectBox <- NULL                                                                                                                                                                    # radio button pour les boxplots
          rb21 <- tk2radiobutton(LabeledFrame1)
          rb22 <- tk2radiobutton(LabeledFrame1)
          rb20Value <- tclVar("ByYears")
@@ -541,6 +540,7 @@ tk2ico.set(Envir$tt, Envir$ico)
          rb2 <- tk2radiobutton(LabeledFrame3)
          rb3 <- tk2radiobutton(LabeledFrame3)
          rb4 <- tk2radiobutton(LabeledFrame3)
+          rbC <- tk2radiobutton(LabeledFrame3)
          rb5 <- tk2radiobutton(LabeledFrame3)
          rb6 <- tk2radiobutton(LabeledFrame3)
          if (is.numeric(Envir$Data$Dates) ==TRUE) { rb2Value <- tclVar("Mean") } else {
@@ -549,17 +549,24 @@ tk2ico.set(Envir$tt, Envir$ico)
          tkconfigure(rb2,variable=rb2Value,value="Median")
          tkconfigure(rb3,variable=rb2Value,value="Quantile")
          tkconfigure(rb4,variable=rb2Value,value="Max")
+         tkconfigure(rbC,variable=rb2Value,value="Other")
+          Fun.C <- tclVar( "" )                                                                                                                   # choix de la valeur de la salinite de standardisation (30 par defaut)
+          entry.Fun <-tk2entry(LabeledFrame3, width="17", textvariable=Fun.C, background="white")
          tkconfigure(rb5,variable=rb2Value,value="help")
          tkconfigure(rb6,variable=rb2Value,value="auto")
-         tkgrid(tklabel(LabeledFrame3,text="Mean "),rb1, sticky="w")
-         tkgrid(tklabel(LabeledFrame3,text="Median "),rb2, sticky="w")
-         tkgrid(tklabel(LabeledFrame3,text="Quantile 0.9 "),rb3, sticky="w")
-         tkgrid(tklabel(LabeledFrame3,text="Maximum "),rb4, sticky="w")
-         tkgrid(tklabel(LabeledFrame3,text="Guidance to choose the method      "),rb5, sticky="w")
-         tkgrid(tklabel(LabeledFrame3,text="Auto "),rb6, sticky="w")
+         tkgrid(tklabel(LabeledFrame3,text="Mean "),rb1, sticky="w", row=1)
+         tkgrid(tklabel(LabeledFrame3,text="Median "),rb2, sticky="w", row=2)
+         tkgrid(tklabel(LabeledFrame3,text="Quantile 0.9 "),rb3, sticky="w", row=3)
+         tkgrid(tklabel(LabeledFrame3,text="Maximum "),rb4, sticky="w", row=4)
+          tkgrid(tklabel(LabeledFrame3,text="Other :"),rbC, sticky="w", row=5)
+          tkgrid(entry.Fun, sticky="n", row=5)
+         tkgrid(tklabel(LabeledFrame3,text="Guidance to choose the method      "),rb5, sticky="w", row=7)
+         tkgrid(tklabel(LabeledFrame3,text="Auto "),rb6, sticky="w", row=8)
 
          tkgrid(tklabel(Envir$datam, text="           "), column=2, row=2)
 
+         tk2tip(rbC, paste("Exemple de fonctions utilisables :","\n","min; max; sum; prod; ","\n","quantile,probs=x / x entre 0 et 1"))
+
      LabeledFrame7 <- tkwidget(Envir$datam,"labelframe",text="Show regularised time series", padx=10, pady=0, relief = "groove")
      tkgrid(LabeledFrame7, column=3, row=2, sticky="n")
      tkgrid(tklabel(LabeledFrame7, text="                                                                                                                                                                            "
@@ -622,6 +629,8 @@ tk2ico.set(Envir$tt, Envir$ico)
           if (rb2Value=="Median"){ aggreg <- "Median" }
           if (rb2Value=="Quantile"){ aggreg <- "Quantile" }
           if (rb2Value=="Max"){ aggreg <- "Max" }
+          if (rb2Value=="Other"){ aggreg <- "Other"
+                                  Envir$fun.choice <- as.character(tclvalue(Fun.C))}
           if (rb2Value=="help"){ help.aggreg <- "YES"
                                  aggreg <- "NULL" }
           else{ help.aggreg <- "N0" }
@@ -691,6 +700,8 @@ tk2ico.set(Envir$tt, Envir$ico)
           if (rb2Value=="Median"){ aggreg <- "Median" }
           if (rb2Value=="Quantile"){ aggreg <- "Quantile" }
           if (rb2Value=="Max"){ aggreg <- "Max" }
+          if (rb2Value=="Other"){ aggreg <- "Other"
+                                  Envir$fun.choice <- as.character(tclvalue(Fun.C))}
           if (rb2Value=="help"){ help.aggreg <- "YES"
                                  aggreg <- "NULL" }
           else{ help.aggreg <- "N0" }
@@ -761,6 +772,8 @@ tk2ico.set(Envir$tt, Envir$ico)
           if (rb2Value=="Median"){ aggreg <- "Median" }
           if (rb2Value=="Quantile"){ aggreg <- "Quantile" }
           if (rb2Value=="Max"){ aggreg <- "Max" }
+          if (rb2Value=="Other"){ aggreg <- "Other"
+                                  Envir$fun.choice <- as.character(tclvalue(Fun.C))}
           if (rb2Value=="help"){ help.aggreg <- "YES"
                                  aggreg <- "NULL" }
           else{ help.aggreg <- "N0" }
@@ -869,6 +882,8 @@ tk2ico.set(Envir$tt, Envir$ico)
           if (rb2Value=="Median"){ aggreg <- "Median" }
           if (rb2Value=="Quantile"){ aggreg <- "Quantile" }
           if (rb2Value=="Max"){ aggreg <- "Max" }
+          if (rb2Value=="Other"){ aggreg <- "Other"
+                                  Envir$fun.choice <- as.character(tclvalue(Fun.C))}
           if (rb2Value=="help"){ help.aggreg <- "YES"
                                  aggreg <- "NULL" }
           else{ help.aggreg <- "N0" }
@@ -921,8 +936,7 @@ tk2ico.set(Envir$tt, Envir$ico)
      rb14 <- tk2radiobutton(testFrame)
      rb15 <- tk2radiobutton(testFrame)
      rb16 <- tk2radiobutton(testFrame)
-     if (is.numeric(Envir$Data$Dates) ==TRUE) { rb4Value <- tclVar("MannKen") } else {
-     rb4Value <- tclVar("seasonMann") }
+     rb4Value <- tclVar("MannKen")
      tkconfigure(rb12,variable=rb4Value,value="seasonMann")                                                # valeur de chaque bouton
      tkconfigure(rb13,variable=rb4Value,value="MannKen")
      tkconfigure(rb14,variable=rb4Value,value="MixingDiagram")
@@ -994,6 +1008,8 @@ tk2ico.set(Envir$tt, Envir$ico)
           if (rb2Value=="Median"){ aggreg <- "Median" }
           if (rb2Value=="Quantile"){ aggreg <- "Quantile" }
           if (rb2Value=="Max"){ aggreg <- "Max" }
+          if (rb2Value=="Other"){ aggreg <- "Other"
+                                  Envir$fun.choice <- as.character(tclvalue(Fun.C))}
           if (rb2Value=="help"){ help.aggreg <- "YES"
                                  aggreg <- "NULL" }
           else{ help.aggreg <- "N0" }
@@ -1047,7 +1063,7 @@ tk2ico.set(Envir$tt, Envir$ico)
 
 #_________________________________________________________________________________________ce qui suit est affiche avant que les donnees ne soit importees
     logoRcran <- tclVar()
-    tcl("image","create","photo",logoRcran,file=file.path(path.package("TTAinterfaceTrendAnalysis"),"aide","Small_Logo_R.gif",fsep=.Platform$file.sep))
+    tcl("image","create","photo",logoRcran,file=file.path(path.package("TTAinterfaceTrendAnalysis"),"aide","Small_Logo_R2.gif",fsep=.Platform$file.sep))
     imgAsLabel2 <- tklabel(Envir$openframe,image=logoRcran)
     tkgrid(imgAsLabel2, column=0, row=1, sticky="w")
 
