@@ -2,7 +2,7 @@ Aide3 <- function () {
 
 aide3 <- tktoplevel()
 tktitle(aide3) <- "Help3 - TimeSeries_building"
-AIDE3 <- tktext(aide3, height=40, width=120)
+AIDE3 <- tktext(aide3, height=41, width=120)
 tkpack(AIDE3)
 tkinsert(AIDE3, "end", paste("This is the third panel of the interface." ,"\n\n",
 
@@ -37,7 +37,8 @@ tkinsert(AIDE3, "end", paste("This is the third panel of the interface." ,"\n\n"
 "     this is the default method." ,"\n\n",
 
 "    _The third box do the same things as the second one but with the mathematical method of" ,"\n",
-"     aggregation instead of frequency."  ,"\n",
+"     aggregation instead of frequency. In <Other> you can tape function such as min; sum; prod"  ,"\n",
+"     or, for quantile, quantile,probs=x where x is between 0 and 1", "\n",
 "     <Guidance to choose the method> perform an Anova with a Dunnett's post-hoc test between the"  ,"\n",
 "     rawdata and the dataset obtain by each method and select the method with the highest p.value" ,"\n",
 "     (less significant differences)." ,"\n\n",
@@ -45,7 +46,7 @@ tkinsert(AIDE3, "end", paste("This is the third panel of the interface." ,"\n\n"
 "    _The <Show regularised time series> buttons let you show the table, the figure or the descriptive statistics"  ,"\n",
 "     of your data passed through the regulation methods you choose. Figure and tables are automatically saved.", sep=""))
      
-tkpack(tk2button(aide3, text="Ok", command=function(){ tkdestroy(aide3) } , width=20 ), side="bottom")
+tkpack(tk2button(aide3, text="OK", command=function(){ tkdestroy(aide3) } , width=20 ), side="bottom")
 tkconfigure(AIDE3, state="disabled", background="white")
 
 }
\ No newline at end of file
